@@ -143,7 +143,8 @@ def _stringify_query():
     from django.db.models.sql.expressions import SQLEvaluator
 
     attrs = {}
-    attrs[WhereNode] = attrs[ExpressionNode] = ('connector', 'negated', 'children', 'subtree_parents')
+    attrs[WhereNode] = attrs[ExpressionNode] \
+        = ('connector', 'negated', 'children', 'subtree_parents')
     attrs[SQLEvaluator] = ('expression',)
     attrs[ExtraWhere] = ('sqls', 'params')
     attrs[Aggregate] = ('source', 'is_summary', 'col', 'extra')
@@ -221,9 +222,10 @@ class QuerySetMixin(object):
 
     def _require_cacheprofile(self):
         if self._cacheprofile is None:
-            raise ImproperlyConfigured('Cacheops is not enabled for %s model.\n'
-                                       'If you don\'t want to cache anything by default you can "just_enable" it.'
-                                        % get_model_name(self.model))
+            raise ImproperlyConfigured(
+                'Cacheops is not enabled for %s model.\n'
+                'If you don\'t want to cache anything by default you can "just_enable" it.'
+                    % get_model_name(self.model))
 
     def _cache_key(self, extra=''):
         """
@@ -392,7 +394,8 @@ class QuerySetMixin(object):
         # TODO: refactor this one to more understandable something
         if self._cacheprofile:
             query_dnf = dnf(self)
-            if len(query_dnf) == 1 and len(query_dnf[0]) == 1 and query_dnf[0][0][0] == self.model._meta.pk.name:
+            if len(query_dnf) == 1 and len(query_dnf[0]) == 1 \
+               and query_dnf[0][0][0] == self.model._meta.pk.name:
                 result = len(self.nocache()) > 0
                 if result:
                     _old_objs[get_model_name(self.model)][query_dnf[0][0][1]] = self._result_cache[0]
@@ -440,7 +443,8 @@ class ManagerMixin(object):
             #       So we strip down any _*_cache attrs before saving
             #       and later reassign them
             # Stripping up undesirable attributes
-            unwanted_attrs = [k for k in instance.__dict__.keys() if k.startswith('_') and k.endswith('_cache')]
+            unwanted_attrs = [k for k in instance.__dict__.keys()
+                                if k.startswith('_') and k.endswith('_cache')]
             unwanted_dict = dict((k, instance.__dict__[k]) for k in unwanted_attrs)
             for k in unwanted_attrs:
                 del instance.__dict__[k]
